==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/TritonModelJobInputArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.TritonModelJobInputArgs.builder
import com.pulumi.azurenative.machinelearningservices.kotlin.enums.InputDeliveryMode
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property description Description for the input.
 * @property jobInputType Enum to determine the Job Input Type.
 * Expected value is 'triton_model'.
 * @property mode Input Asset Delivery Mode.
 * @property uri [Required] Input Asset URI.
 */
public data class TritonModelJobInputArgs(
    public val description: Output<String>? = null,
    public val jobInputType: Output<String>,
    public val mode: Output<Either<String, InputDeliveryMode>>? = null,
    public val uri: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.TritonModelJobInputArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.TritonModelJobInputArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.TritonModelJobInputArgs.builder()
            .description(description?.applyValue({ args0 -> args0 }))
            .jobInputType(jobInputType.applyValue({ args0 -> args0 }))
            .mode(
                mode?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .uri(uri.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TritonModelJobInputArgs].
 */
@PulumiTagMarker
public class TritonModelJobInputArgsBuilder internal constructor() {
    private var description: Output<String>? = null

    private var jobInputType: Output<String>? = null

    private var mode: Output<Either<String, InputDeliveryMode>>? = null

    private var uri: Output<String>? = null

    /**
     * @param value Description for the input.
     */
    @JvmName("eyccqxwfotbgtdyb")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value Enum to determine the Job Input Type.
     * Expected value is 'triton_model'.
     */
    @JvmName("ibjgftflpuxlyohc")
    public suspend fun jobInputType(`value`: Output<String>) {
        this.jobInputType = value
    }

    /**
     * @param value Input Asset Delivery Mode.
     */
    @JvmName("fsctnytrlwloaxnf")
    public suspend fun mode(`value`: Output<Either<String, InputDeliveryMode>>) {
        this.mode = value
    }

    /**
     * @param value [Required] Input Asset URI.
     */
    @JvmName("ilakopitsldmmpjj")
    public suspend fun uri(`value`: Output<String>) {
        this.uri = value
    }

    /**
     * @param value Description for the input.
     */
    @JvmName("nmobnxfenebtcqhw")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value Enum to determine the Job Input Type.
     * Expected value is 'triton_model'.
     */
    @JvmName("hbefjrsmcoqwsokh")
    public suspend fun jobInputType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.jobInputType = mapped
    }

    /**
     * @param value Input Asset Delivery Mode.
     */
    @JvmName("uvawlbauswlqsnmd")
    public suspend fun mode(`value`: Either<String, InputDeliveryMode>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.mode = mapped
    }

    /**
     * @param value Input Asset Delivery Mode.
     */
    @JvmName("gcuohrraosctvqfs")
    public fun mode(`value`: String) {
        val toBeMapped = Either.ofLeft<String, InputDeliveryMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.mode = mapped
    }

    /**
     * @param value Input Asset Delivery Mode.
     */
    @JvmName("nplyixqanhvoepyk")
    public fun mode(`value`: InputDeliveryMode) {
        val toBeMapped = Either.ofRight<String, InputDeliveryMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.mode = mapped
    }

    /**
     * @param value [Required] Input Asset URI.
     */
    @JvmName("qfyqbddwjpmanawd")
    public suspend fun uri(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.uri = mapped
    }

    internal fun build(): TritonModelJobInputArgs = TritonModelJobInputArgs(
        description = description,
        jobInputType = jobInputType ?: throw PulumiNullFieldException("jobInputType"),
        mode = mode,
        uri = uri ?: throw PulumiNullFieldException("uri"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/TritonModelJobInputArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.TritonModelJobInputArgs.builder
import com.pulumi.azurenative.machinelearningservices.kotlin.enums.InputDeliveryMode
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property description Description for the input.
 * @property jobInputType Enum to determine the Job Input Type.
 * Expected value is 'triton_model'.
 * @property mode Input Asset Delivery Mode.
 * @property uri [Required] Input Asset URI.
 */
public data class TritonModelJobInputArgs(
    public val description: Output<String>? = null,
    public val jobInputType: Output<String>,
    public val mode: Output<Either<String, InputDeliveryMode>>? = null,
    public val uri: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.TritonModelJobInputArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.TritonModelJobInputArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.TritonModelJobInputArgs.builder()
            .description(description?.applyValue({ args0 -> args0 }))
            .jobInputType(jobInputType.applyValue({ args0 -> args0 }))
            .mode(
                mode?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .uri(uri.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TritonModelJobInputArgs].
 */
@PulumiTagMarker
public class TritonModelJobInputArgsBuilder internal constructor() {
    private var description: Output<String>? = null

    private var jobInputType: Output<String>? = null

    private var mode: Output<Either<String, InputDeliveryMode>>? = null

    private var uri: Output<String>? = null

    /**
     * @param value Description for the input.
     */
    @JvmName("gxmedacnafijtjqm")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value Enum to determine the Job Input Type.
     * Expected value is 'triton_model'.
     */
    @JvmName("ytmkvxyystagwiyb")
    public suspend fun jobInputType(`value`: Output<String>) {
        this.jobInputType = value
    }

    /**
     * @param value Input Asset Delivery Mode.
     */
    @JvmName("qgqwfltpckwhbsca")
    public suspend fun mode(`value`: Output<Either<String, InputDeliveryMode>>) {
        this.mode = value
    }

    /**
     * @param value [Required] Input Asset URI.
     */
    @JvmName("auwdkdblgfpascvi")
    public suspend fun uri(`value`: Output<String>) {
        this.uri = value
    }

    /**
     * @param value Description for the input.
     */
    @JvmName("yrhprsnmdbcbufdr")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value Enum to determine the Job Input Type.
     * Expected value is 'triton_model'.
     */
    @JvmName("vofyocbteidevaud")
    public suspend fun jobInputType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.jobInputType = mapped
    }

    /**
     * @param value Input Asset Delivery Mode.
     */
    @JvmName("ltbwktryywcvvgfh")
    public suspend fun mode(`value`: Either<String, InputDeliveryMode>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.mode = mapped
    }

    /**
     * @param value Input Asset Delivery Mode.
     */
    @JvmName("caluxkeqoflaapwc")
    public fun mode(`value`: String) {
        val toBeMapped = Either.ofLeft<String, InputDeliveryMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.mode = mapped
    }

    /**
     * @param value Input Asset Delivery Mode.
     */
    @JvmName("clhjwrpdqkyhylkw")
    public fun mode(`value`: InputDeliveryMode) {
        val toBeMapped = Either.ofRight<String, InputDeliveryMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.mode = mapped
    }

    /**
     * @param value [Required] Input Asset URI.
     */
    @JvmName("koewyfxjiqqrjhbk")
    public suspend fun uri(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.uri = mapped
    }

    internal fun build(): TritonModelJobInputArgs = TritonModelJobInputArgs(
        description = description,
        jobInputType = jobInputType ?: throw PulumiNullFieldException("jobInputType"),
        mode = mode,
        uri = uri ?: throw PulumiNullFieldException("uri"),
    )
}
